@@ -538,7 +538,6 @@ class AggregationAgent(SFNAgent):
         data_df,
         column_text_describe_dict,
         group_by_columns,
-        feature_dtype_dict,
         use_case=None,
     ) -> Dict[str, List[Dict[str, Any]]]:
         """
@@ -547,17 +546,25 @@ class AggregationAgent(SFNAgent):
         logger.info("Suggesting aggregation methods")
 
         try:
+            df_columns = [col.lower() for col in data_df.columns]
+            group_by_columns = [col.lower() for col in group_by_columns]
 
             for col in column_text_describe_dict.keys():
-                if col not in data_df.columns:
+                if col.lower() not in df_columns:
                     logger.info(
                         f"Key '{col}' in column_text_describe_dict but not found as a column in data_df."
                     )
 
             for col in group_by_columns:
-                if col not in data_df.columns:
+                if col.lower() not in df_columns:
                     raise ValueError(f"Group by column '{col}' not found in data_df.")
 
+            df_inferred = data_df.convert_dtypes()
+            feature_dtype_dict = {}
+
+            for column_name, dtype in df_inferred.dtypes.items():
+                convert_dtype = self.get_column_category(dtype)
+                feature_dtype_dict[column_name] = convert_dtype
 
             if len(data_df) == len(data_df.groupby(group_by_columns)):
                 logger.info(
@@ -589,13 +596,9 @@ class AggregationAgent(SFNAgent):
                     if col in group_by_columns:
                         continue
 
-                    dtype = feature_dtype_dict.get(col)
-                    if dtype in default_methods:
-                        aggregation_suggestion[col] = [default_methods[dtype]]
-                    else:
-                        logger.info(
-                             f"    Warning: Data type for column '{col}' not recognized, skipping."
-                            )
+                    col_type = feature_dtype_dict[col]
+                    method_info = default_methods[col_type]
+                    aggregation_suggestion[col] = [method_info]
 
                 return aggregation_suggestion, {}
 
